Module analysis

Module analysis 

Structs

DuplicateSet
VersionMetadata
Holds metadata fetched from the Cargo registry. Only the following metrics are stored:

Functions

find_duplicates
find_optimal_version
Asynchronously selects the optimal version based solely on Cargo registry metrics. For each candidate version, the following steps are taken: