Structs
- Duplicate
Set - Version
Metadata - Holds metadata fetched from the Cargo registry. Only the following metrics are stored:
Functions
- find_
duplicates - find_
optimal_ version - Asynchronously selects the optimal version based solely on Cargo registry metrics. For each candidate version, the following steps are taken: